@@ -14,7 +14,10 @@ from ax.core import (
     FixedParameter,
     GeneratorRun,
     Metric,
+    MultiObjective,
+    MultiObjectiveOptimizationConfig,
     Objective,
+    ObjectiveThreshold,
     OptimizationConfig,
     OrderConstraint,
     OutcomeConstraint,
@@ -50,7 +53,10 @@ __all__ = [
     "GeneratorRun",
     "Metric",
     "Models",
+    "MultiObjective",
+    "MultiObjectiveOptimizationConfig",
     "Objective",
+    "ObjectiveThreshold",
     "OptimizationConfig",
     "OptimizationLoop",
     "OrderConstraint",
