@@ -511,7 +511,6 @@ class Experiment(Base):
             )
             if combine_with_last_data and len(current_trial_data) > 0:
                 last_ts, last_data = list(current_trial_data.items())[-1]
-                # pyre-fixme[16]: Module `pd` has no attribute `merge`.
                 merged = pd.merge(
                     last_data.df,
                     trial_df,
@@ -621,10 +620,10 @@ class Experiment(Base):
 
         Args:
             generator_run: GeneratorRun, associated with this trial.
-                Trial has only one generator run (and thus arm)
-                attached to it. This can also be set later through `add_arm`
-                or `add_generator_run`, but a trial's associated generator run is
-                immutable once set.
+                Trial has only one arm attached to it and this generator_run
+                must therefore contain one arm. This arm can also be set later
+                through `add_arm` or `add_generator_run`, but a trial's
+                associated generator run is immutable once set.
             trial_type: Type of this trial, if used in MultiTypeExperiment.
             ttl_seconds: If specified, trials will be considered failed after
                 this many seconds since the time the trial was ran, unless the
