@@ -9,6 +9,7 @@ from enum import Enum
 from typing import Dict, List, Optional, Type, Union
 
 from ax.core.types import TParamValue
+from ax.exceptions.core import UserInputError
 from ax.utils.common.base import Base
 
 
@@ -123,7 +124,7 @@ class RangeParameter(Parameter):
             target_value: Target value of this parameter if it is a fidelity.
         """
         if is_fidelity and (target_value is None):
-            raise ValueError(
+            raise UserInputError(
                 "`target_value` should not be None for the fidelity parameter: "
                 "{}".format(name)
             )
@@ -152,17 +153,17 @@ class RangeParameter(Parameter):
             ParameterType.INT,
             ParameterType.FLOAT,
         ):
-            raise ValueError("RangeParameter type must be int or float.")
+            raise UserInputError("RangeParameter type must be int or float.")
         # pyre-fixme[58]: `>=` is not supported for operand types `Union[None, bool,
         #  float, int, str]` and `Union[None, bool, float, int, str]`.
         if lower >= upper:
-            raise ValueError("max must be strictly larger than min.")
+            raise UserInputError("max must be strictly larger than min.")
         # pyre-fixme[58]: `<=` is not supported for operand types `Union[None, bool,
         #  float, int, str]` and `int`.
         if log_scale and lower <= 0:
-            raise ValueError("Cannot take log when min <= 0.")
+            raise UserInputError("Cannot take log when min <= 0.")
         if not (self.is_valid_type(lower)) or not (self.is_valid_type(upper)):
-            raise ValueError(
+            raise UserInputError(
                 f"[{lower}, {upper}] is an invalid range for this parameter."
             )
 
@@ -220,6 +221,7 @@ class RangeParameter(Parameter):
             lower = self._lower
         if upper is None:
             upper = self._upper
+
         cast_lower = self.cast(lower)
         cast_upper = self.cast(upper)
         self._validate_range_param(
@@ -238,7 +240,7 @@ class RangeParameter(Parameter):
         # pyre-fixme[58]: `>=` is not supported for operand types `Union[None, bool,
         #  float, int, str]` and `Union[None, bool, float, int, str]`.
         if cast_lower >= cast_upper:
-            raise ValueError(
+            raise UserInputError(
                 f"Lower bound {cast_lower} is >= upper bound {cast_upper}."
             )
 
@@ -350,7 +352,7 @@ class ChoiceParameter(Parameter):
             target_value: Target value of this parameter if it's fidelity.
         """
         if is_fidelity and (target_value is None):
-            raise ValueError(
+            raise UserInputError(
                 "`target_value` should not be None for the fidelity parameter: "
                 "{}".format(name)
             )
@@ -363,7 +365,7 @@ class ChoiceParameter(Parameter):
         self._target_value = self.cast(target_value)
         # A choice parameter with only one value is a FixedParameter.
         if not len(values) > 1:
-            raise ValueError(FIXED_CHOICE_PARAM_ERROR)
+            raise UserInputError(FIXED_CHOICE_PARAM_ERROR)
         self._values = self._cast_values(values)
 
     @property
@@ -396,7 +398,7 @@ class ChoiceParameter(Parameter):
         """
         # A choice parameter with only one value is a FixedParameter.
         if not len(values) > 1:
-            raise ValueError(FIXED_CHOICE_PARAM_ERROR)
+            raise UserInputError(FIXED_CHOICE_PARAM_ERROR)
         self._values = self._cast_values(values)
         return self
 
@@ -473,7 +475,7 @@ class FixedParameter(Parameter):
             target_value: Target value of this parameter if it is a fidelity.
         """
         if is_fidelity and (target_value is None):
-            raise ValueError(
+            raise UserInputError(
                 "`target_value` should not be None for the fidelity parameter: "
                 "{}".format(name)
             )
