@@ -23,9 +23,9 @@ from ax.models.torch.botorch_modular.utils import (
 )
 from ax.models.torch.utils import _to_inequality_constraints
 from ax.models.torch_base import TorchModel
+from ax.utils.common.base import Base
 from ax.utils.common.constants import Keys
 from ax.utils.common.docutils import copy_doc
-from ax.utils.common.equality import Base
 from ax.utils.common.typeutils import checked_cast, not_none
 from botorch.acquisition.acquisition import AcquisitionFunction
 from torch import Tensor
@@ -54,13 +54,21 @@ class BoTorchModel(TorchModel, Base):
         surrogate: An instance of `Surrogate` to be used as part of
             this model; if not specified, type of `Surrogate` and
             underlying BoTorch `Model` will be auto-selected based
-            on experiment and data.
+            on experiment and data, with kwargs in `surrogate_options`
+            applied.
+        surrogate_options: Optional dict of kwargs for `Surrogate`
+            (used if no pre-instantiated Surrogate via is passed via `surrogate`).
         surrogate_fit_options: Optional dict of kwargs, passed to
-            `Surrogate.fit`, like `state_dict` or `refit_on_update`.
+            `Surrogate.fit`, including:
+                - state_dict: `state_dict` for the underlying BoTorch
+                  `Model`,
+                - refit_on_update: Whether to re-fit the underlying
+                  BoTorch `Model` when updating it with new data.
     """
 
     acquisition_class: Type[Acquisition]
-    acquisition_options: TConfig
+    acquisition_options: Dict[str, Any]
+    surrogate_options: Dict[str, Any]
     surrogate_fit_options: Dict[str, Any]
     _surrogate: Optional[Surrogate]
     _botorch_acqf_class: Optional[Type[AcquisitionFunction]]
@@ -68,12 +76,20 @@ class BoTorchModel(TorchModel, Base):
     def __init__(
         self,
         acquisition_class: Optional[Type[Acquisition]] = None,
-        acquisition_options: Optional[TConfig] = None,
+        acquisition_options: Optional[Dict[str, Any]] = None,
         botorch_acqf_class: Optional[Type[AcquisitionFunction]] = None,
         surrogate: Optional[Surrogate] = None,
+        surrogate_options: Optional[Dict[str, Any]] = None,
         surrogate_fit_options: Optional[Dict[str, Any]] = None,
     ) -> None:
         self._surrogate = surrogate
+        if surrogate and surrogate_options:
+            raise ValueError(  # pragma: no cover
+                "`surrogate_options` are only applied when using the default "
+                "surrogate, so only one of `surrogate` and `surrogate_options`"
+                " arguments is expected."
+            )
+        self.surrogate_options = surrogate_options or {}
         self.surrogate_fit_options = surrogate_fit_options or {}
         self.acquisition_class = acquisition_class or Acquisition
         # `_botorch_acqf_class` can be set to `None` here. If so,
@@ -95,8 +111,6 @@ class BoTorchModel(TorchModel, Base):
             raise ValueError("BoTorch `AcquisitionFunction` has not yet been set.")
         return not_none(self._botorch_acqf_class)
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `Xs` expected.
     @copy_doc(TorchModel.fit)
     def fit(
         self,
@@ -151,14 +165,10 @@ class BoTorchModel(TorchModel, Base):
             refit=self.surrogate_fit_options.get(Keys.REFIT_ON_UPDATE, True),
         )
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `X` expected.
     @copy_doc(TorchModel.predict)
     def predict(self, X: Tensor) -> Tuple[Tensor, Tensor]:
         return self.surrogate.predict(X=X)
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `bounds` expected.
     @copy_doc(TorchModel.gen)
     def gen(
         self,
@@ -205,8 +215,6 @@ class BoTorchModel(TorchModel, Base):
             None,
         )
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `bounds` expected.
     @copy_doc(TorchModel.best_point)
     def best_point(
         self,
@@ -220,8 +228,6 @@ class BoTorchModel(TorchModel, Base):
     ) -> Optional[Tensor]:
         raise NotImplementedError("Coming soon.")
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `bounds` expected.
     @copy_doc(TorchModel.evaluate_acquisition_function)
     def evaluate_acquisition_function(
         self,
@@ -270,7 +276,7 @@ class BoTorchModel(TorchModel, Base):
         if use_model_list(Xs=Xs, botorch_model_class=botorch_model_class):
             # If using `ListSurrogate` / `ModelListGP`, pick submodels for each
             # outcome.
-            botorch_model_class_per_outcome = {
+            botorch_submodel_class_per_outcome = {
                 metric_name: choose_model_class(
                     Yvars=[Yvar],
                     task_features=task_features,
@@ -279,12 +285,15 @@ class BoTorchModel(TorchModel, Base):
                 for Yvar, metric_name in zip(Yvars, metric_names)
             }
             self._surrogate = ListSurrogate(
-                botorch_model_class_per_outcome=botorch_model_class_per_outcome
+                botorch_submodel_class_per_outcome=botorch_submodel_class_per_outcome,
+                **self.surrogate_options
             )
         else:
             # Using regular `Surrogate`, so botorch model picked at the beginning
             # of the function is the one we should use.
-            self._surrogate = Surrogate(botorch_model_class=botorch_model_class)
+            self._surrogate = Surrogate(
+                botorch_model_class=botorch_model_class, **self.surrogate_options
+            )
 
     def _bounds_as_tensor(self, bounds: List[Tuple[float, float]]) -> Tensor:
         bounds_ = torch.tensor(
