@@ -202,6 +202,7 @@ class MultiObjectiveBotorchModel(BotorchModel):
         refit_on_cv: bool = False,
         refit_on_update: bool = True,
         warm_start_refitting: bool = False,
+        use_input_warping: bool = False,
         **kwargs: Any,
     ) -> None:
         self.model_constructor = model_constructor
@@ -214,6 +215,7 @@ class MultiObjectiveBotorchModel(BotorchModel):
         self.refit_on_cv = refit_on_cv
         self.refit_on_update = refit_on_update
         self.warm_start_refitting = warm_start_refitting
+        self.use_input_warping = use_input_warping
         self.model: Optional[Model] = None
         self.Xs = []
         self.Ys = []
